summaryrefslogtreecommitdiff
path: root/sql/wsrep_mysqld.cc
diff options
context:
space:
mode:
Diffstat (limited to 'sql/wsrep_mysqld.cc')
-rw-r--r--sql/wsrep_mysqld.cc3
1 files changed, 2 insertions, 1 deletions
diff --git a/sql/wsrep_mysqld.cc b/sql/wsrep_mysqld.cc
index d41229bad2b..5fd14e566a6 100644
--- a/sql/wsrep_mysqld.cc
+++ b/sql/wsrep_mysqld.cc
@@ -456,9 +456,10 @@ void wsrep_init_schema()
unireg_abort(1);
}
// If we are bootstraping new cluster we should
// populate allowlist from variable
if (wsrep_new_cluster)
{
+ wsrep_schema->clear_allowlist();
std::vector<std::string> ip_allowlist;
if (wsrep_split_allowlist(ip_allowlist))
{
@@ -456,9 +456,10 @@ void wsrep_init_schema()
}
// If we are bootstraping new cluster we should
- // populate allowlist from variable
+ // clear allowlist table and populate it from variable
if (wsrep_new_cluster)
{